function figures_generator_beads()

% This script generates Figures 4a-d, 5, 6a-f
% of the work
% Coplanar electrode microfluidic chip enabling accurate sheathless impedance cytometry
% by A. De Ninno, V. Errico, F. R. Bertani, L. Businaro, P. Bisegna, and F. Caselli
% Lab Chip, (2017), DOI: 10.1039/c6lc01516f.
%
% It has been developed using Matlab R2016b

clear
close all
clc

% number of bead populations
n_p=3;
% nominal diameters of each population
D=[5.2,6,7];
% label of each population
lbl={'a','b','c'};

% data filnames
filename   =cell(1,n_p+1);
% -------------------------------------------------------------------------
% 5 um beads: population 1
filename{1}='5um_beads';
% -------------------------------------------------------------------------
% 6 um beads: population 2
filename{2}='6um_beads';
% -------------------------------------------------------------------------
% 7 um beads: population 3
filename{3}='7um_beads';
% -------------------------------------------------------------------------
% 5,6,7 um mix beads
filename{4}='5_6_7um_beads_mix';


%  parameters relevant to compansation
compensation_fit_param=struct('c1',0.98, 'c2', 0.13, 'c3', 0.30);

%  parameters relevant to post-processing

% font size
fnt_sz=16; % please use a larger value (e.g., 24) for earlier Matlab versions

% linewidth
lw=2;

% number of bins in histograms
n_bin_electric_D=200;
n_bin_rel_prm   =200;
n_bin_velocity  =200;

% axis limits
electric_D_lim     =[4.5,9.5];
electric_D_norm_lim=[0.8,1.6];
velocity_lim       =[0.1,0.5];
rel_prm_lim        =[0,1];

% color for each population
color={'g','r',[255, 128 ,0]/256};

% ymax for population histograms
ymax_all=3500;
ymax_mix=3000;

% print device and resolution
print_device='-dtiff';
print_resolution='-r300';


% -------------------------------------------------------------------------
% read data (features of fitted templates)
% -------------------------------------------------------------------------
% separate runs (1..n_p)
electric_D_cell=cell(1,n_p);
% velocity_cell=cell(1,n_p);
rel_prm_cell=cell(1,n_p);
for p=1:n_p
    load([filename{p},'.mat'],'electric_D', 'velocity', 'rel_prm');
    electric_D_cell{p}=electric_D;
    % velocity_cell{p}  =velocity;
    rel_prm_cell{p}=rel_prm;
end
% mix (n_p+1)
load([filename{n_p+1},'.mat'],'electric_D', 'velocity', 'rel_prm');
electric_D_mix=electric_D;
velocity_mix=velocity;
rel_prm_mix=rel_prm;


% -------------------------------------------------------------------------
% scatter plots electric_D vs rel_prm
% -------------------------------------------------------------------------
for p=1:n_p
    figure()
    histogram2(electric_D_cell{p},rel_prm_cell{p},'DisplayStyle','tile','ShowEmptyBins','on', ...
        'NumBins',[n_bin_electric_D,n_bin_rel_prm],'XBinLimits',electric_D_lim,'YBinLimits',rel_prm_lim);
    colorbar
    xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
    ylabel('Relative prominence {\itP}','FontSize',fnt_sz)
    set(gca,'FontSize',fnt_sz)
    print(['Figure_4',lbl{p}],print_device,print_resolution)
end

% all populations together
electric_D_all=[];
rel_prm_all=[];
for p=1:n_p
    electric_D_all=[electric_D_all,electric_D_cell{p}];
    rel_prm_all=[rel_prm_all,rel_prm_cell{p}];
end

figure()
histogram2(electric_D_all,rel_prm_all,'DisplayStyle','tile','ShowEmptyBins','on', ...
    'NumBins',[n_bin_electric_D,n_bin_rel_prm],'XBinLimits',electric_D_lim,'YBinLimits',rel_prm_lim);
colorbar
xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
ylabel('Relative prominence {\itP}','FontSize',fnt_sz)
set(gca,'FontSize',fnt_sz)
print('Figure_4d',print_device,print_resolution)


% -------------------------------------------------------------------------
% prominence-based calibration
% -------------------------------------------------------------------------
% all normalized data
electric_D_norm_calibration=[];
rel_prm_calibration=[];
for p=1:n_p
    electric_D_norm_calibration=[electric_D_norm_calibration, electric_D_cell{p}/D(p)];
    rel_prm_calibration=[rel_prm_calibration, rel_prm_cell{p}];
end

figure()
histogram2(electric_D_norm_calibration,rel_prm_calibration,'DisplayStyle','tile','ShowEmptyBins','on', ...
    'NumBins',[n_bin_electric_D,n_bin_rel_prm],'XBinLimits',electric_D_norm_lim,'YBinLimits',rel_prm_lim);
colorbar
xlabel('Normalized electrical diameter {\itD/d}','FontSize',fnt_sz)
ylabel('Relative prominence {\itP}','FontSize',fnt_sz)
set(gca,'FontSize',fnt_sz)

% -------------------------------------------------------------------------
% fit visual check
% plot fit curve on previous figure
hold on

% extract compensation parameters
c1=compensation_fit_param.c1;
c2=compensation_fit_param.c2;
c3=compensation_fit_param.c3;

% fit curve
rel_prm_calibration_vals=0.08:0.001:0.85;
electric_D_fit = c1+c2*rel_prm_calibration_vals+c3*rel_prm_calibration_vals.^2;

plot(electric_D_fit,rel_prm_calibration_vals,'or','MarkerSize',5)
print('Figure_5',print_device,print_resolution)


% -------------------------------------------------------------------------
% compensation on all populations together
% -------------------------------------------------------------------------

electric_D_comp_cell=cell(1,n_p);
% parabolic fit: D/d=c1+c2*P+c3*P^2
% compensation formula
for p=1:n_p
    electric_D_comp_cell{p}=electric_D_cell{p} ./ ( c1+c2*rel_prm_cell{p}+c3*rel_prm_cell{p}.^2 );
end

figure()
hold on
for p=1:n_p
    histogram(electric_D_cell{p},'NumBins',n_bin_electric_D,'BinLimits',electric_D_lim,'EdgeColor',color{p},'FaceColor',color{p});
end
xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
ylabel('Count','FontSize',fnt_sz)
xlim(electric_D_lim)
ylim([0,ymax_all])
set(gca,'FontSize',fnt_sz)
box on
print('Figure_6a',print_device,print_resolution)

figure()
hold on
for p=1:n_p
    histogram(electric_D_comp_cell{p},'NumBins',n_bin_electric_D,'BinLimits',electric_D_lim,'EdgeColor',color{p},'FaceColor',color{p});
end
xlabel('Corrected electrical diameter {\itD}-corr [\mum]','FontSize',fnt_sz)
ylabel('Count','FontSize',fnt_sz)
xlim(electric_D_lim)
ylim([0,ymax_all])
set(gca,'FontSize',fnt_sz)
box on
print('Figure_6d',print_device,print_resolution)


% -------------------------------------------------------------------------
% compensation on mix
% -------------------------------------------------------------------------

% parabolic fit: D/d=c1+c2*P+c3*P^2
% compensation
electric_D_mix_comp=electric_D_mix ./ ( c1+c2*rel_prm_mix+c3*rel_prm_mix.^2 );

figure()
hold on
histogram(electric_D_mix,'NumBins',n_bin_electric_D,'BinLimits',electric_D_lim,'EdgeColor','b','FaceColor','b');
xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
ylabel('Count','FontSize',fnt_sz)
xlim(electric_D_lim)
ylim([0,ymax_mix])
set(gca,'FontSize',fnt_sz)
box on
print('Figure_6b',print_device,print_resolution)

figure()
hold on
h_comp=histogram(electric_D_mix_comp,'NumBins',n_bin_electric_D,'BinLimits',electric_D_lim,'EdgeColor','b','FaceColor','b');
xlabel('Corrected electrical diameter {\itD}-corr [\mum]','FontSize',fnt_sz)
ylabel('Count','FontSize',fnt_sz)
xlim(electric_D_lim)
ylim([0,ymax_mix])
set(gca,'FontSize',fnt_sz)


% -------------------------------------------------------------------------
% Gaussian fit on population distributions
% -------------------------------------------------------------------------

% bin centers
bc=(h_comp.BinEdges(1:end-1)+h_comp.BinEdges(2:end))/2;
% count
count=h_comp.Values;

% fit
[a, x_c, sigma, gof]=multiple_Gaussian_fit(bc, count, n_p, D);

% population boundaries
D_bou=[0, (D(1:end-1)+D(2:end))/2, inf];

% cumulative numbers
cum_num=zeros(1,n_p);
for p=1:n_p
    cum_num(p)=sum(count(bc<D_bou(p+1)));
end
% effetive numbers
pop_num=diff([0,cum_num]);
disp('effective bead numbers')
disp(pop_num)
disp('total')
disp(sum(pop_num))
% fit
% number of points
n_fit=10*n_bin_electric_D;
bc_fit=linspace(electric_D_lim(1),electric_D_lim(2),n_fit);
% plot fit curve
% model string
model=[];
for p=1:n_p
    ps=['(',num2str(p),')'];
    model=[model, ' + a',ps,'*exp(-(bc_fit-x_c',ps,').^2/(2*sigma',ps,'.^2))'];
end
count_fit=eval(model);
plot(bc_fit,count_fit,'r','linewidth',lw)
box on
print('Figure_6e',print_device,print_resolution)

% coefficient of variation
CV=sigma./x_c;
disp('x_c')
disp(x_c)
disp('sigma')
disp(sigma)
disp('CV')
disp(CV)


% -------------------------------------------------------------------------
% velocity vs. diameter scatter plots
% -------------------------------------------------------------------------

figure()
histogram2(electric_D_mix,velocity_mix,'DisplayStyle','tile','ShowEmptyBins','on', ...
    'NumBins',[n_bin_electric_D,n_bin_velocity],'XBinLimits',electric_D_lim,'YBinLimits',velocity_lim);
colorbar
xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
ylabel('Velocity [m/s]','FontSize',fnt_sz)
set(gca,'FontSize',fnt_sz)
box on
print('Figure_6c',print_device,print_resolution)

figure()
histogram2(electric_D_mix_comp,velocity_mix,'DisplayStyle','tile','ShowEmptyBins','on', ...
    'NumBins',[n_bin_electric_D,n_bin_velocity],'XBinLimits',electric_D_lim,'YBinLimits',velocity_lim);
colorbar
xlabel('Corrected electrical diameter {\itD}-corr [\mum]','FontSize',fnt_sz)
ylabel('Velocity [m/s]','FontSize',fnt_sz)
set(gca,'FontSize',fnt_sz)
box on
print('Figure_6f',print_device,print_resolution)

end
