function figures_generator_yeasts()

% This script generates Figures 7, 8a-d
% of the work
% Coplanar electrode microfluidic chip enabling accurate sheathless impedance cytometry
% by A. De Ninno, V. Errico, F. R. Bertani, L. Businaro, P. Bisegna, and F. Caselli
% Lab Chip, (2017), DOI: 10.1039/c6lc01516f.
%
% It has been developed using Matlab R2016b

clear
close all
clc

% number of populations: yeast; 6um beads
n_p=2;

% data filnames
filename   =cell(1,n_p+1);
% -------------------------------------------------------------------------
% yeast and 6 um beads mix
filename{n_p+1}='yeasts_spiked_with_6um_beads';


%  parameters relevant to compansation
compensation_fit_param=struct('c1',0.98, 'c2', 0.13, 'c3', 0.30);

%  parameters relevant to post-processing

% font size
fnt_sz=16; % please use a larger value (e.g., 24) for earlier Matlab versions

% linewidth
lw=3.5;

% number of bins in histograms
n_bin_electric_D=200;
n_bin_rel_prm   =200;
n_bin_velocity  =200;

% axis limits
electric_D_lim     =[2,9];
velocity_lim       =[0.1,0.5];
rel_prm_lim        =[-0.05,1];

% color for each population
color={'b','r'};
color_fit={[51,170,255]/255,[255,55,55]/255,[51,170,255]/255};

% ymax for population histograms
ymax_all=2500;

% print device and resolution
print_device='-dtiff';
print_resolution='-r300';


% -------------------------------------------------------------------------
% read data (features of fitted templates and classification)
% -------------------------------------------------------------------------
% mix (n_p+1)
load([filename{n_p+1},'.mat'],'electric_D', 'velocity', 'rel_prm', 'bead', 'yeast');
electric_D_mix=electric_D;
velocity_mix=velocity;
rel_prm_mix=rel_prm;

% extract populations
electric_D_cell=cell(1,n_p);
velocity_cell=cell(1,n_p);
rel_prm_cell=cell(1,n_p);
% yeast
electric_D_cell{1}=electric_D(yeast);
velocity_cell{1}=velocity(yeast);
rel_prm_cell{1}=rel_prm(yeast);
% beads
electric_D_cell{2}=electric_D(bead);
velocity_cell{2}=velocity(bead);
rel_prm_cell{2}=rel_prm(bead);

% -------------------------------------------------------------------------
% scatter plots electric_D vs rel_prm
% -------------------------------------------------------------------------
% all populations together
electric_D_all=[];
rel_prm_all=[];
velocity_all=[];
for p=1:n_p
    electric_D_all=[electric_D_all,electric_D_cell{p}];
    rel_prm_all=[rel_prm_all,rel_prm_cell{p}];
    velocity_all=[velocity_all,velocity_cell{p}];
end

figure()
histogram2(electric_D_all,rel_prm_all,'DisplayStyle','tile','ShowEmptyBins','on', ...
    'NumBins',[n_bin_electric_D,n_bin_rel_prm],'XBinLimits',electric_D_lim,'YBinLimits',rel_prm_lim);
colorbar
xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
ylabel('Relative prominence {\itP}','FontSize',fnt_sz)
set(gca,'FontSize',fnt_sz)
print('Figure_7',print_device,print_resolution)


% -------------------------------------------------------------------------
% scatter plots electric_D vs velocity
% -------------------------------------------------------------------------
figure()
histogram2(electric_D_all,velocity_all,'DisplayStyle','tile','ShowEmptyBins','on', ...
    'NumBins',[n_bin_electric_D,n_bin_velocity],'XBinLimits',electric_D_lim,'YBinLimits',velocity_lim);
colorbar
xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
ylabel('Velocity [m/s]','FontSize',fnt_sz)
set(gca,'FontSize',fnt_sz)
box on
print('Figure_8b',print_device,print_resolution)



% -------------------------------------------------------------------------
% compensation on all populations together
% -------------------------------------------------------------------------

electric_D_comp_cell=cell(1,n_p);
% parabolic fit: D/d=c1+c2*P+c3*P^2
% extract compensation parameters
c1=compensation_fit_param.c1;
c2=compensation_fit_param.c2;
c3=compensation_fit_param.c3;
% compensation
for p=1:n_p
    electric_D_comp_cell{p}=electric_D_cell{p} ./ ( c1+c2*rel_prm_cell{p}+c3*rel_prm_cell{p}.^2 );
end

figure()
hold on
for p=1:n_p
    histogram(electric_D_cell{p},'NumBins',n_bin_electric_D,'BinLimits',electric_D_lim,'EdgeColor',color{p},'FaceColor',color{p});
end
xlabel('Electrical diameter {\itD} [\mum]','FontSize',fnt_sz)
ylabel('Count','FontSize',fnt_sz)
xlim(electric_D_lim)
ylim([0,ymax_all])
set(gca,'FontSize',fnt_sz)
box on
print('Figure_8a',print_device,print_resolution)

h_comp_fig=figure();
hold on
h_comp=cell(1,n_p);
for p=1:n_p
    h_comp{p}=histogram(electric_D_comp_cell{p},'NumBins',n_bin_electric_D,'BinLimits',electric_D_lim,'EdgeColor',color{p},'FaceColor',color{p});
end
xlabel('Corrected electrical diameter {\itD}-corr [\mum]','FontSize',fnt_sz)
ylabel('Count','FontSize',fnt_sz)
xlim(electric_D_lim)
ylim([0,ymax_all])
set(gca,'FontSize',fnt_sz)
box on
print('Figure_8c',print_device,print_resolution)

% -------------------------------------------------------------------------
% compensation on mix
% -------------------------------------------------------------------------

% parabolic fit: D/d=c1+c2*P+c3*P^2
% compensation
electric_D_mix_comp=electric_D_mix ./ ( c1+c2*rel_prm_mix+c3*rel_prm_mix.^2 );

% -------------------------------------------------------------------------
% scatter plots corrected electric_D vs velocity
% -------------------------------------------------------------------------
figure()
histogram2(electric_D_mix_comp,velocity_mix,'DisplayStyle','tile','ShowEmptyBins','on', ...
    'NumBins',[n_bin_electric_D,n_bin_velocity],'XBinLimits',electric_D_lim,'YBinLimits',velocity_lim);
colorbar
xlabel('Corrected electrical diameter {\itD}-corr [\mum]','FontSize',fnt_sz)
ylabel('Velocity [m/s]','FontSize',fnt_sz)
set(gca,'FontSize',fnt_sz)
box on
print('Figure_8d',print_device,print_resolution)



% -------------------------------------------------------------------------
% Gaussian fit on population distributions
% -------------------------------------------------------------------------
yeast=1;
bead=2;

figure(h_comp_fig)
box on

% -------------------------------------------------------------------------
% yeast
% bin centers
bc=(h_comp{yeast}.BinEdges(1:end-1)+h_comp{yeast}.BinEdges(2:end))/2;
% count
count=h_comp{yeast}.Values;

% fit
n_p_yeast=2;
D_yeast=[4.4, 5.5];
[a, x_c, sigma, gof]=multiple_Gaussian_fit(bc, count, n_p_yeast, D_yeast);

% number of points
n_fit=10*n_bin_electric_D;
bc_fit=linspace(electric_D_lim(1),electric_D_lim(2),n_fit);

% plot overall fit curve
% model string
model=[];
for p=1:n_p
    ps=['(',num2str(p),')'];
    model=[model, ' + a',ps,'*exp(-(bc_fit-x_c',ps,').^2/(2*sigma',ps,'.^2))'];
end
count_fit=eval(model);
plot(bc_fit,count_fit,'Color',color_fit{yeast},'linewidth',lw)

% plot fit curve for each population
% model string
for p=1:n_p
    ps=['(',num2str(p),')'];
    model=[' + a',ps,'*exp(-(bc_fit-x_c',ps,').^2/(2*sigma',ps,'.^2))'];
    count_fit=eval(model);
    plot(bc_fit,count_fit,':','Color',color_fit{yeast},'linewidth',lw)
end

% -------------------------------------------------------------------------
% beads
% bin centers
bc=(h_comp{bead}.BinEdges(1:end-1)+h_comp{bead}.BinEdges(2:end))/2;
% count
count=h_comp{bead}.Values;

% fit
n_p_bead=1;
D_bead=6;
[a, x_c, sigma, gof]=multiple_Gaussian_fit(bc, count, n_p_bead, D_bead);

% number of points
n_fit=10*n_bin_electric_D;
bc_fit=linspace(electric_D_lim(1),electric_D_lim(2),n_fit);

% plot fit curve
% model string
model=[' + a*exp(-(bc_fit-x_c).^2/(2*sigma.^2))'];
count_fit=eval(model);
plot(bc_fit,count_fit,'Color',color_fit{bead},'linewidth',lw)

print('Figure_8c',print_device,print_resolution)

end